package PayServer

import (
	"encoding/json"
	"game/base/log"
	"game/base/platApi"
	"game/base/util"
	"game/config"
	"game/excel"
	"io/ioutil"
	"net/http"
	"strings"
)

func QQPreOrder(w http.ResponseWriter, r *http.Request) {
	var data []byte
	defer func() {
		w.Write(data)
	}()

	if r.Method != "POST" {
		return
	}

	r.ParseForm()
	openid := r.Form.Get("openid")
	//uid := r.Form.Get("uid")
	zone := r.Form.Get("sid")
	item := r.Form.Get("produce")
	sessionKey := r.Form.Get("session")
	//amt := r.Form.Get("amt")
	//amount := util.StringToUint32(r.Form.Get("amount"))
	amt := "1"
	amount := uint32(1)
	token := platApi.GetAppAccessToken(config.QQAppID, config.QQAppSecret, platApi.Plat_QQ)

	ret, err := platApi.QQPrePay(openid, config.QQAppID, zone, amt, item, amount, token, sessionKey)
	if err != nil {
		log.Error(err)
		return
	}

	data, _ = json.Marshal(ret)
	log.Info("QQPreOrder ret:", ret)
}

func (srv *PayServer) QQPayCallBack(w http.ResponseWriter, r *http.Request) {
	ret := &platApi.QQPayCallBackRet{}
	defer func() {
		log.Info("QQPayCallBack ret:", ret)
		data, _ := json.Marshal(ret)
		w.Write(data)
	}()

	body, e := r.GetBody()
	if e != nil {
		return
	}
	rData, e := ioutil.ReadAll(body)
	if e != nil {
		return
	}

	req := &platApi.QQPayCallBack{}
	err := json.Unmarshal(rData, req)
	if err != nil {
		return
	}
	log.Info(" req:", req)

	ok := platApi.QQCallBackVerify(req, r.URL.Path, config.QQAppSecret)
	if !ok {
		ret.Code = 1
		ret.Msg = "签名检验失败"
		return
	}

	extInfo := strings.Split(req.AppRemark, "-")
	if len(extInfo) != 3 {
		ret.Code = 2
		ret.Msg = "app_remark参数格式错误"
		return
	}

	sid := util.StringToInt(extInfo[0])
	produce := util.StringToUint32(extInfo[1])
	uid := util.StringToUint64(extInfo[2])

	info := excel.GetPlatformIdById(produce)
	msg := &RechargeCommonC2SMsg{
		RoleId:     uid,
		Rmb:        float32(info.Money),
		ChargeYb:   info.Money * 10,
		GiftYb:     0,
		OrderId:    r.FormValue("bill_no"),
		POrderId:   r.FormValue("bill_no"),
		PlatformIp: r.Header.Get("X-Real_IP"),
		AttType:    info.Type,
		AttValue:   info.Index,
	}
	code, _ := srv.DeliverGood(sid, msg)
	if code == 1 || code == 1002 {
		ret.Code = 0
	} else {
		ret.Code = 3
	}
	log.Info("QQCallback DeliverRecv sid:", sid, " Role:", uid, " OrderId:", msg.OrderId, " POrderId:", msg.POrderId,
		" Money:", info.Money, " produce:", produce, " Code:", ret.Code, " code:", code, " err:", err)

	//TODO 发货
	//var serverId uint64
	//var uid uint64
	//var id uint32
	//var orderId string
	//msg := &protoMsg.PToL_PaySuccessMsg{
	//	Uid:     uid,
	//	Id:      id,
	//	Channel: common.Pay_QQ,
	//	OrderID: orderId,
	//}
	//srv.Send(serverId, uid, int32(protoMsg.CMD_IN_PToL_PaySuccess), msg)
}
